@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: ispell.c,v 1.128 1994/10/26 05:12:28 geoff Exp $";
+    "$Id: ispell.c,v 1.131 1995/01/08 23:23:39 geoff Exp $";
 #endif
 
 #define MAIN
@@ -49,6 +49,19 @@ static char Rcs_Id[] =
 
 /*
  * $Log: ispell.c,v $
+ * Revision 1.131  1995/01/08  23:23:39  geoff
+ * Support variable hashfile suffixes for DOS purposes.  Report all the
+ * new configuration variables in the -vv switch.  Do some better error
+ * checking for mktemp failures.  Support the rename system call.  All of
+ * this is to help make DOS porting easier.
+ *
+ * Revision 1.130  1995/01/03  19:24:08  geoff
+ * When constructing a personal-dictioary name from the hash file name,
+ * don't stupidly include path directory components.
+ *
+ * Revision 1.129  1995/01/03  02:23:19  geoff
+ * Disable the setbuf call on BSDI systems, sigh.
+ *
  * Revision 1.128  1994/10/26  05:12:28  geoff
  * Include boundary characters in the list of characters to be tried in
  * corrections.
@@ -248,8 +261,8 @@ int main (argc, argv)
 	else
 	    (void) sprintf (hashname, "%s/%s", LIBDIR, p);
 	p = rindex (p, '.');
-	if (p == NULL  ||  strcmp (p, ".hash") != 0)
-	    (void) strcat (hashname, ".hash");
+	if (p == NULL  ||  strcmp (p, HASHSUFFIX) != 0)
+	    (void) strcat (hashname, HASHSUFFIX);
 	}
     else
 	(void) sprintf (hashname, "%s/%s", LIBDIR, DEFHASH);
@@ -315,6 +328,7 @@ int main (argc, argv)
 		    (void) printf ("\t!CONTEXTROUNDUP\n");
 #endif /* CONTEXTROUNDUP */
 		    (void) printf ("\tCONTEXTPCT = %d\n", CONTEXTPCT);
+		    (void) printf ("\tCOUNTSUFFIX = \"%s\"\n", COUNTSUFFIX);
 		    (void) printf ("\tDEFHASH = \"%s\"\n", DEFHASH);
 		    (void) printf ("\tDEFINCSTR = \"%s\"\n", DEFINCSTR);
 		    (void) printf ("\tDEFLANG = \"%s\"\n", DEFLANG);
@@ -336,6 +350,13 @@ int main (argc, argv)
 #else /* GENERATE_LIBRARY_PROTOS */
 		    (void) printf ("\t!GENERATE_LIBRARY_PROTOS\n");
 #endif /* GENERATE_LIBRARY_PROTOS */
+#ifdef HAS_RENAME
+		    (void) printf ("\tHAS_RENAME\n");
+#else /* HAS_RENAME */
+		    (void) printf ("\t!HAS_RENAME\n");
+#endif /* HAS_RENAME */
+		    (void) printf ("\tHASHSUFFIX = \"%s\"\n", HASHSUFFIX);
+		    (void) printf ("\tHOME = \"%s\"\n", HOME);
 #ifdef IGNOREBIB
 		    (void) printf ("\tIGNOREBIB\n");
 #else /* IGNOREBIB */
@@ -384,6 +405,8 @@ int main (argc, argv)
 		    (void) printf ("\t!MINIMENU\n");
 #endif /* MINIMENU */
 		    (void) printf ("\tMINWORD = %d\n", MINWORD);
+		    (void) printf ("\tMSDOS_BINARY_OPEN = 0x%x\n",
+		      (unsigned int) MSDOS_BINARY_OPEN);
 		    (void) printf ("\tMSGLANG = %s\n", MSGLANG);
 #ifdef NO_CAPITALIZATION_SUPPORT
 		    (void) printf ("\tNO_CAPITALIZATION_SUPPORT\n");
@@ -403,6 +426,11 @@ int main (argc, argv)
 		    (void) printf ("\tNRSPECIAL = \"%s\"\n", NRSPECIAL);
 		    (void) printf ("\tOLDPAFF = \"%s\"\n", OLDPAFF);
 		    (void) printf ("\tOLDPDICT = \"%s\"\n", OLDPDICT);
+#ifdef PDICTHOME
+		    (void) printf ("\tPDICTHOME = \"%s\"\n", PDICTHOME);
+#else /* PDICTHOME */
+		    (void) printf ("\tPDICTHOME = (undefined)\n");
+#endif /* PDICTHOME */
 		    (void) printf ("\tPDICTVAR = \"%s\"\n", PDICTVAR);
 #ifdef PIECEMEAL_HASH_WRITES
 		    (void) printf ("\tPIECEMEAL_HASH_WRITES\n");
@@ -420,6 +448,7 @@ int main (argc, argv)
 		    (void) printf ("\tREGLIB = \"%s\"\n", REGLIB);
 		    (void) printf ("\tSIGNAL_TYPE = %s\n", SIGNAL_TYPE_STRING);
 		    (void) printf ("\tSORTPERSONAL = %d\n", SORTPERSONAL);
+		    (void) printf ("\tSTATSUFFIX = \"%s\"\n", STATSUFFIX);
 		    (void) printf ("\tTEMPNAME = \"%s\"\n", TEMPNAME);
 		    (void) printf ("\tTERMLIB = \"%s\"\n", TERMLIB);
 		    (void) printf ("\tTEXINFODIR = \"%s\"\n", TEXINFODIR);
@@ -613,10 +642,13 @@ int main (argc, argv)
 		if (cpd == NULL  &&  *p != '\0')
 		    LibDict = p;
 		p = rindex (p, '.');
-		if (p != NULL  &&  strcmp (p, ".hash") == 0)
+		if (p != NULL  &&  strcmp (p, HASHSUFFIX) == 0)
 		    *p = '\0';	/* Don't want ext. in LibDict */
 		else
-		    (void) strcat (hashname, ".hash");
+		    (void) strcat (hashname, HASHSUFFIX);
+		p = rindex (LibDict, '/');
+		if (p != NULL)
+		    LibDict = p + 1;
 		break;
 	    case 'V':		/* Display 8-bit characters as M-xxx */
 		if (arglen > 2)
@@ -702,7 +734,7 @@ int main (argc, argv)
 	(void) strcpy (libdictname, DEFHASH);
 	LibDict = libdictname;
 	p = rindex (libdictname, '.');
-	if (p != NULL  &&  strcmp (p, ".hash") == 0)
+	if (p != NULL  &&  strcmp (p, HASHSUFFIX) == 0)
 	    *p = '\0';	/* Don't want ext. in LibDict */
 	}
     if (!nodictflag)
@@ -725,7 +757,9 @@ int main (argc, argv)
 	exit (0);
 	}
 
+#ifndef __bsdi__
     setbuf (stdout, outbuf);
+#endif /* __bsdi__ */
     if (lflag)
 	{
 	infile = stdin;
@@ -782,10 +816,12 @@ static void dofile (filename)
 
     (void) fstat (fileno (infile), &statbuf);
     (void) strcpy (tempfile, TEMPNAME);
-    (void) mktemp (tempfile);
-    if ((outfile = fopen (tempfile, "w")) == NULL)
+    if (mktemp (tempfile) == NULL  ||  tempfile[0] == '\0'
+      ||  (outfile = fopen (tempfile, "w")) == NULL)
 	{
-	(void) fprintf (stderr, CANT_CREATE, tempfile);
+	(void) fprintf (stderr, CANT_CREATE,
+	  (tempfile == NULL  ||  tempfile[0] == '\0')
+	    ? "temporary file" : tempfile);
 	(void) sleep ((unsigned) 2);
 	return;
 	}
@@ -852,8 +888,12 @@ static void update_file (filename, statbuf)
 	pathtail++;
     if (strncmp (filename, bakfile, pathtail - bakfile + MAXNAMLEN) != 0)
 	(void) unlink (bakfile);	/* unlink so we can write a new one. */
+#ifdef HAS_RENAME
+    (void) rename (filename, bakfile);
+#else /* HAS_RENAME */
     if (link (filename, bakfile) == 0)
 	(void) unlink (filename);
+#endif /* HAS_RENAME */
 
     /* if we can't write new, preserve .bak regardless of xflag */
     if ((outfile = fopen (filename, "w")) == NULL)
