@@ -1,5 +1,5 @@
 /*
- * $Id: ispell.h,v 1.65 1994/11/02 06:56:10 geoff Exp $
+ * $Id: ispell.h,v 1.67 1995/01/03 19:24:12 geoff Exp $
  */
 
 /*
@@ -42,6 +42,13 @@
 
 /*
  * $Log: ispell.h,v $
+ * Revision 1.67  1995/01/03  19:24:12  geoff
+ * Get rid of a non-global declaration.
+ *
+ * Revision 1.66  1994/12/27  23:08:49  geoff
+ * Fix a lot of subtly bad assumptions about the widths of ints and longs
+ * which only show up on 64-bit machines like the Cray and the DEC Alpha.
+ *
  * Revision 1.65  1994/11/02  06:56:10  geoff
  * Remove the anyword feature, which I've decided is a bad idea.
  *
@@ -102,19 +109,19 @@ extern int	TSTMASKBIT P ((MASKTYPE * mask, int bit));
 #else /* lint */
 /* The following is really testing for MASKSIZE <= 1, but cpp can't do that */
 #if MASKBITS <= MASKTYPE_WIDTH
-#define SETMASKBIT(mask, bit) ((mask)[0] |= 1 << (bit))
-#define CLRMASKBIT(mask, bit) ((mask)[0] &= ~(1 << (bit)))
-#define TSTMASKBIT(mask, bit) ((mask)[0] & (1 << (bit)))
+#define SETMASKBIT(mask, bit) ((mask)[0] |= (MASKTYPE) 1 << (bit))
+#define CLRMASKBIT(mask, bit) ((mask)[0] &= (MASKTYPE) ~(1 << (bit)))
+#define TSTMASKBIT(mask, bit) ((mask)[0] & ((MASKTYPE) 1 << (bit)))
 #else
 #define SETMASKBIT(mask, bit) \
 		    ((mask)[(bit) / MASKTYPE_WIDTH] |= \
-		      1 << ((bit) & (MASKTYPE_WIDTH - 1)))
+		      (MASKTYPE) 1 << ((bit) & (MASKTYPE_WIDTH - 1)))
 #define CLRMASKBIT(mask, bit) \
 		    ((mask)[(bit) / MASKTYPE_WIDTH] &= \
-		      ~(1 << ((bit) & (MASKTYPE_WIDTH - 1))))
+		      ~((MASKTYPE) 1 << ((bit) & (MASKTYPE_WIDTH - 1))))
 #define TSTMASKBIT(mask, bit) \
 		    ((mask)[(bit) / MASKTYPE_WIDTH] & \
-		      (1 << ((bit) & (MASKTYPE_WIDTH - 1))))
+		      ((MASKTYPE) 1 << ((bit) & (MASKTYPE_WIDTH - 1))))
 #endif
 #endif /* lint */
 
@@ -133,7 +140,7 @@ extern int	CHARTOBIT P ((int ch));
 #define CHARTOBIT(ch)	((ch) - 'A')
 # endif /* lint */
 #define LARGESTFLAG	26	/* 5 are needed for flagfield below */
-#define FLAGBASE	26
+#define FLAGBASE	(MASKTYPE_WIDTH - 6)
 #else
 # if MASKBITS <= 64
 #  ifndef lint
@@ -141,7 +148,7 @@ extern int	CHARTOBIT P ((int ch));
 #define CHARTOBIT(ch)	((ch) - 'A')
 #  endif /* lint */
 #define LARGESTFLAG	(64 - 6) /* 5 are needed for flagfield below */
-#define FLAGBASE	26
+#define FLAGBASE	(MASKTYPE_WIDTH - 6)
 # else
 #  ifndef lint
 #define BITTOCHAR(bit)	(bit)
@@ -255,17 +262,17 @@ struct dent
 #else
 #define flagfield	mask[MASKSIZE - 1]
 #endif
-#define USED		(1 << (FLAGBASE + 0))
-#define KEEP		(1 << (FLAGBASE + 1))
+#define USED		((MASKTYPE) 1 << (FLAGBASE + 0))
+#define KEEP		((MASKTYPE) 1 << (FLAGBASE + 1))
 #ifdef NO_CAPITALIZATION_SUPPORT
 #define ALLFLAGS	(USED | KEEP)
 #else /* NO_CAPITALIZATION_SUPPORT */
-#define ANYCASE		(0 << (FLAGBASE + 2))
-#define ALLCAPS		(1 << (FLAGBASE + 2))
-#define CAPITALIZED	(2 << (FLAGBASE + 2))
-#define FOLLOWCASE	(3 << (FLAGBASE + 2))
-#define CAPTYPEMASK	(3 << (FLAGBASE + 2))
-#define MOREVARIANTS	(1 << (FLAGBASE + 4))
+#define ANYCASE		((MASKTYPE) 0 << (FLAGBASE + 2))
+#define ALLCAPS		((MASKTYPE) 1 << (FLAGBASE + 2))
+#define CAPITALIZED	((MASKTYPE) 2 << (FLAGBASE + 2))
+#define FOLLOWCASE	((MASKTYPE) 3 << (FLAGBASE + 2))
+#define CAPTYPEMASK	((MASKTYPE) 3 << (FLAGBASE + 2))
+#define MOREVARIANTS	((MASKTYPE) 1 << (FLAGBASE + 4))
 #define ALLFLAGS	(USED | KEEP | CAPTYPEMASK | MOREVARIANTS)
 #define captype(x)	((x) & CAPTYPEMASK)
 #endif /* NO_CAPITALIZATION_SUPPORT */
@@ -630,4 +637,3 @@ INIT (int math_mode, 0);
  * m -- looking for a \begin{minipage} argument.
  */
 INIT (char LaTeX_Mode, 'P');
-INIT (int TeX_comment, 0);
